package com.caimei365.manager.controller.caimei.user;

import cn.hutool.poi.excel.ExcelUtil;
import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.CmBehaviorRecord;
import com.caimei365.manager.entity.caimei.CmPageType;
import com.caimei365.manager.service.caimei.user.CmBehaviorRecordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.swing.filechooser.FileSystemView;
import java.io.File;
import java.net.URLEncoder;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/3/15
 */
@RestController
@RequestMapping("/user/behavior")
public class CmBehaviorRecordApi {

    @Autowired private CmBehaviorRecordService recordService;

    /**
     * 获取父标签
     * @param keyword
     * @return
     */
    @GetMapping("/getKeyword")
    public ResponseJson getKeyword(String keyword) {

        return recordService.getKeyword(keyword);
    }

    /**
     * 获取页面类型
     * @param pageLabels
     * @return
     */
    @GetMapping("/getPageType")
    public ResponseJson<List<CmPageType>> getPageType(String pageLabels) {

        return recordService.getPageType(pageLabels);
    }

    /**
     * 用户行为记录列表数据
     * @param cmBehaviorRecord 参数
     * @return 返回
     */
    @GetMapping("/record/list")
    public ResponseJson<PaginationVo<CmBehaviorRecord>> list(CmBehaviorRecord cmBehaviorRecord,
                                                             @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                             @RequestParam(value = "pageSize",defaultValue = "20") int pageSize) {

        return recordService.list(cmBehaviorRecord, pageNum, pageSize);
    }

    /**
     * 今日数据导出
     * @param cmBehaviorRecord
     * @param response
     * @return
     */
    @GetMapping("/exportToday")
    public void exportExcel(CmBehaviorRecord cmBehaviorRecord, HttpServletResponse response) {
        String name = "今日数据";
        try {
            List<CmBehaviorRecord> RecordList = recordService.exportExcel(cmBehaviorRecord);

            response.setContentType("application/vnd.ms-excel");
            response.setCharacterEncoding("utf-8");
            // 这里URLEncoder.encode可以防止中文乱码 当然和easyexcel没有关系
            String fileName = URLEncoder.encode(name, "UTF-8").replaceAll("\\+", "%20");
            response.setHeader("Content-disposition", "attachment;filename*=utf-8''" + fileName + ".xlsx");
            EasyExcel.write(response.getOutputStream(), cmBehaviorRecord.getClass()).autoCloseStream(Boolean.TRUE).sheet("数据").doWrite(RecordList);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 查看详情
     * @param cmBehaviorRecord 参数
     * @param pageNum 页码
     * @param pageSize 页面数据数
     * @return 返回
     */
    @GetMapping("/record/recordList")
    public ResponseJson<PaginationVo<CmBehaviorRecord>> recordList (CmBehaviorRecord cmBehaviorRecord,
                                                                    @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                    @RequestParam(value = "pageSize",defaultValue = "20")int pageSize) {
        return recordService.recordList(cmBehaviorRecord, pageNum, pageSize);
    }

    /**
     * 标签库数据
     * @return 返回
     */
    @GetMapping("/searchList")
    public ResponseJson searchList () {

        return recordService.searchList();
    }
}
