package com.caimei365.manager.controller.wechat;

import com.caimei365.manager.config.security.ConstantKey;
import com.caimei365.manager.config.security.JwtService;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.wechat.WechatText;
import com.caimei365.manager.service.wechat.WechatTextService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

/**
 * 微信公众号-文本素材
 *
 * @author : Charles
 * @date : 2022/1/6
 */
@RestController
@RequestMapping("/wechat/text")
public class WechatTextApi {

    @Resource
    private WechatTextService wechatTextService;
    @Resource
    private JwtService jwtService;

    /**
     * 获取文本素材列表
     *
     * @param type 类型： 1采美，2呵呵商城
     * @param title 标题
     * @param pageNum  页码
     * @param pageSize 每页大小
     */
    @GetMapping("/list")
    public ResponseJson<PaginationVo<WechatText>> textList(Integer type, String title,
                                                             @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                             @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return wechatTextService.getTextList(type, title, pageNum, pageSize);
    }

    /**
     * 根据ID获取文本素材
     */
    @GetMapping("/{id}")
    public ResponseJson<WechatText> getText(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("文本素材Id不能为空！", null);
        }
        return wechatTextService.getText(id);
    }

    /**
     * 根据ID更新文本素材
     */
    @PostMapping("/update/{id}")
    public ResponseJson<Void> updateText(HttpServletRequest request, @PathVariable("id") Integer id, @RequestBody WechatText text) {
        if (null == id || id <= 0) {
            return ResponseJson.error("文本素材Id不能为空！", null);
        }
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return wechatTextService.updateText(id, text, username);
    }

    /**
     * 添加文本素材
     */
    @PostMapping("/create")
    public ResponseJson<Void> addText(HttpServletRequest request, @RequestBody WechatText text) {
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return wechatTextService.addText(text, username);
    }

    /**
     * 根据ID删除文本素材
     */
    @PostMapping("/delete/{id}")
    public ResponseJson<Void> deleteText(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("文本素材Id不能为空！", null);
        }
        return wechatTextService.deleteText(id);
    }
}
