package com.caimei365.manager.service.caimei.listener;

import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.alibaba.fastjson.JSON;
import com.caimei365.manager.dao.KeyWordDao;
import com.caimei365.manager.entity.caimei.KeyWord;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class KeywordListener extends AnalysisEventListener<KeyWord> {

    @Resource
    private KeyWordDao keyWordDao;

    /**
     * 批处理阈值
     */
    private static final int BATCH_COUNT = 20;
    List<KeyWord> list = new ArrayList<>(BATCH_COUNT);

    /**
     * 数据解析
     *
     * @param keyword
     * @param analysisContext
     */
    @Override
    public void invoke(KeyWord keyword, AnalysisContext analysisContext) {
        log.info("解析到一条数据:{}", JSON.toJSONString(keyword));
        list.add(keyword);
        if (list.size() >= BATCH_COUNT) {
            importItemInfo(list);
            list.clear();
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext analysisContext) {
        importItemInfo(list);
        log.info("所有数据解析完成！");
    }

    /**
     * 插入数据
     *
     * @param infoList
     */
    public void importItemInfo(List<KeyWord> infoList) {
        infoList.forEach(k -> {
            Integer id = keyWordDao.findKeywordExist(k.getKeyword());
            if (null == id) {
                keyWordDao.insertLabelByExcel(k.getKeyword());
            }
        });
    }
}
